package AccessCheck::App::ValidateChallenge;

use Mojo::Base qw(AccessCheck::App::Controller);

use DateTime;
use Email::MIME;
use Email::Sender::Simple;
use English qw(-no_match_vars);
use Syntax::Keyword::Try;
use Template::Constants qw(:chomp);

use AccessCheck::Data::Token;
use AccessCheck::Regexp;
use AccessCheck::Tools;

sub run {
    my $self = shift;

    my $app    = $self->app();
    my $config = $app->config();
    my $log    = $app->log();

    my $l10n = $self->init_l10n();
    my $user = $self->init_user();
    my $db   = $self->init_db();

    if ($config->{app}->{login_url}) {
        return if !$self->check_authentication();
    }

    my $entityid = $self->param('entityid');
    my $email    = $self->param('email');

    my $sp = $self->get_sp(entityid => $entityid);
    return if !$sp;

    return $self->abort(
        log_message  => "Missing parameter: email",
        user_message => "missing_email"
    ) if !$email;

    return $self->abort(
        log_message  => "Invalid parameter: email",
        user_message => "invalid_email"
    ) if $email !~ $AccessCheck::Regexp::email;

    my $base_templates_dir = $self->app()->home()->child('templates');
    my $profiles = $base_templates_dir
        ->child('accounts')
        ->list()
        ->map(sub { m/([^\/]+).tt2$/})
        ->to_array();

    $self->stash(entityid => $entityid);
    $self->stash(email    => $email);
    $self->stash(validity => $config->{service}->{account_validity_period});
    $self->stash(profiles => $profiles);

    $self->render(
        status   => 200,
        template => 'validate_challenge',
        format   => 'html'
    );
}

1;
